namespace elm { namespace interface { namespace atspi { 
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<int>::type Selection::selected_children_count_get() const
{
   int __return_value =  ::elm_interface_atspi_selection_selected_children_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits< ::eo::Base>::type Selection::selected_child_get( ::efl::eolian::in_traits<int>::type selected_child_index) const
{
    ::Eo_Base* __return_value =  ::elm_interface_atspi_selection_selected_child_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(selected_child_index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::eo::Base>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Selection::child_select( ::efl::eolian::in_traits<int>::type child_index) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_selection_child_select(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(child_index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Selection::selected_child_deselect( ::efl::eolian::in_traits<int>::type child_index) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_selection_selected_child_deselect(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(child_index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Selection::is_child_selected( ::efl::eolian::in_traits<int>::type child_index) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_selection_is_child_selected(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(child_index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Selection::all_children_select() const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_selection_all_children_select(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Selection::clear() const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_selection_clear(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Selection::child_deselect( ::efl::eolian::in_traits<int>::type child_index) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_selection_child_deselect(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(child_index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
} } } 
namespace eo_cxx {
namespace elm { namespace interface { namespace atspi { 
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<int>::type Selection::selected_children_count_get() const
{
   int __return_value =  ::elm_interface_atspi_selection_selected_children_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits< ::eo::Base>::type Selection::selected_child_get( ::efl::eolian::in_traits<int>::type selected_child_index) const
{
    ::Eo_Base* __return_value =  ::elm_interface_atspi_selection_selected_child_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(selected_child_index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::eo::Base>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Selection::child_select( ::efl::eolian::in_traits<int>::type child_index) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_selection_child_select(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(child_index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Selection::selected_child_deselect( ::efl::eolian::in_traits<int>::type child_index) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_selection_selected_child_deselect(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(child_index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Selection::is_child_selected( ::efl::eolian::in_traits<int>::type child_index) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_selection_is_child_selected(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(child_index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Selection::all_children_select() const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_selection_all_children_select(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Selection::clear() const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_selection_clear(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_SELECTION_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Selection::child_deselect( ::efl::eolian::in_traits<int>::type child_index) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_selection_child_deselect(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(child_index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
inline elm::interface::atspi::Selection::operator ::elm::interface::atspi::Selection() const { return *static_cast< ::elm::interface::atspi::Selection const*>(static_cast<void const*>(this)); }
inline elm::interface::atspi::Selection::operator ::elm::interface::atspi::Selection&() { return *static_cast< ::elm::interface::atspi::Selection*>(static_cast<void*>(this)); }
inline elm::interface::atspi::Selection::operator ::elm::interface::atspi::Selection const&() const { return *static_cast< ::elm::interface::atspi::Selection const*>(static_cast<void const*>(this)); }
} } } }

